.. _child_example_two-name:

!!!!!!!!!!!!!!!!!
child_example_two
!!!!!!!!!!!!!!!!!

.. meta::
   :keywords: child_example_two,second,child,example,page,links,this,file

.. index:: child_example_two, second, child, page

.. _child_example_two-title:

Second Child Example Page
#########################

.. contents::
   :local:

.. index:: links

.. _child_example_two@Links:

Links
*****
- :ref:`parent<toc_list_example-title>`
- :ref:`first child<child_example_one-title>`
- :ref:`third child<child_example_three-title>`

.. _child_example_two@This Example File:

This Example File
*****************

.. literalinclude:: ../../example/children.xrst
   :language: rst
